@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""Global control parameters for Gaussian
-"""
+"""Global control parameters for Gaussian"""
 
 import logging
 
@@ -45,6 +44,9 @@ class EnergyParameters(seamm.Parameters):
                 "6-31G",
                 "6-31G*",
                 "6-31G**",
+                "6-311G",
+                "6-311G*",
+                "6-311G**",
                 "cc-pVDZ",
                 "cc-pVTZ",
                 "cc-pVQZ",
@@ -57,6 +59,42 @@ class EnergyParameters(seamm.Parameters):
             "description": "Basis:",
             "help_text": ("The basis set to use."),
         },
+        "checkpoint": {
+            "default": "default",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("default", "job:gaussian.chk"),
+            "format_string": "s",
+            "description": "Checkpoint file:",
+            "help_text": "The checkpoint file to use.",
+        },
+        "initial checkpoint": {
+            "default": "default",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("default", "job:gaussian.chk"),
+            "format_string": "s",
+            "description": "Initial checkpoint file:",
+            "help_text": "The initial checkpoint file to start with.",
+        },
+        "geometry": {
+            "default": "current",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("current", "from configuration", "from checkpoint file"),
+            "format_string": "s",
+            "description": "Geometry:",
+            "help_text": "Where to get the geometry.",
+        },
+        "initial wavefunction": {
+            "default": "default",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": ("default", "Read", "Harris", "Core"),
+            "format_string": "s",
+            "description": "Initial wavefunction:",
+            "help_text": "The starting wavefunction for the calculation.",
+        },
         "method": {
             "default": "DFT: Kohn-Sham density functional theory",
             "kind": "enumeration",
@@ -96,7 +134,7 @@ class EnergyParameters(seamm.Parameters):
             "help_text": ("The exchange-correlation functional to use."),
         },
         "dispersion": {
-            "default": "GD3BJ",
+            "default": "none",
             "kind": "enumeration",
             "default_units": "",
             "enumeration": ["none", "GD3BJ", "GD3", "DG2"],
@@ -129,6 +167,25 @@ class EnergyParameters(seamm.Parameters):
                 "maximum change in the density matrix (10^-(N+2))."
             ),
         },
+        "integral grid": {
+            "default": "UltraFine",
+            "kind": "enumeration",
+            "default_units": "",
+            "enumeration": (
+                "96,32,64",
+                "SuperFine",
+                "UltraFine",
+                "Fine",
+                "SG1",
+                "Coarse",
+            ),
+            "format_string": "s",
+            "description": "Numerical grid:",
+            "help_text": (
+                "The grid to use for numerical integrations in e.g. DFT. "
+                "The 'UltraFine' is the normal default for Gaussian."
+            ),
+        },
         "maximum iterations": {
             "default": "default",
             "kind": "integer",
@@ -179,6 +236,73 @@ class EnergyParameters(seamm.Parameters):
                 "Whether to freeze the core orbitals in correlated " "methods"
             ),
         },
+        "bond orders": {
+            "default": "Wiberg",
+            "kind": "enumeration",
+            "default_units": "",
+            "enumeration": ("Wiberg", "none"),
+            "format_string": "s",
+            "description": "Calculate bond orders:",
+            "help_text": "Whether to calculate the bond orders and if so how.",
+        },
+        "apply bond orders": {
+            "default": "yes",
+            "kind": "bool",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "",
+            "description": "Apply bond orders to structure:",
+            "help_text": (
+                "Whether to use the calculated bond orders to update the structure"
+            ),
+        },
+        "save standard orientation": {
+            "default": "yes",
+            "kind": "boolean",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "s",
+            "description": "Save standard orientation:",
+            "help_text": "Keep the standard orientation rather than input orientation.",
+        },
+        "print basis set": {
+            "default": "no",
+            "kind": "boolean",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "s",
+            "description": "Print basis set:",
+            "help_text": "Whether to print the basis set to the output.",
+        },
+        "save basis set": {
+            "default": "no",
+            "kind": "str",
+            "default_units": "",
+            "enumeration": ("yes", "no", "append to"),
+            "format_string": "s",
+            "description": "Save basis set:",
+            "help_text": "Whether to save the basis set to a file.",
+        },
+        "basis set file": {
+            "default": "basis.gbs",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": tuple(),
+            "format_string": "s",
+            "description": "File for basis set:",
+            "help_text": "The file for the output basis set.",
+        },
+        "file handling": {
+            "default": "remove checkpoint files",
+            "kind": "string",
+            "format_string": "s",
+            "enumeration": ("keep all", "remove all", "remove checkpoint files"),
+            "description": "File handling",
+            "help_text": (
+                "How to handle files after a successful calculation."
+                "or 'advanced', which shows everything."
+            ),
+        },
         "results": {
             "default": {},
             "kind": "dictionary",
