@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""Non-graphical part of the Gaussian step in a SEAMM flowchart
-"""
+"""Non-graphical part of the Gaussian step in a SEAMM flowchart"""
 
 import logging
 import pkg_resources
@@ -338,6 +337,13 @@ class Gaussian(seamm.Node):
                 node.run()
             node = node.next()
 
+        # Handle any cleanup of files requested
+        node = self.subflowchart.get_node("1").next()
+        while node is not None:
+            if node.is_runable:
+                node.cleanup()
+            node = node.next()
+
         return next_node
 
     def analyze(self, indent="", fchk=[], output=[], configuration=None, **kwargs):
