@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""Global control parameters for Gaussian
-"""
+"""Global control parameters for Gaussian"""
 
 import logging
 
@@ -57,11 +56,41 @@ class OptimizationParameters(gaussian_step.EnergyParameters):
             "description": "Convergence criteria:",
             "help_text": "The criteria to use for convergence.",
         },
+        "hessian": {
+            "default": "default guess",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": (
+                "default guess",
+                "read from checkpoint",
+                "calculate",
+                "from property on configuration",
+            ),
+            # "from previous step",
+            "format_string": "",
+            "description": "Hessian:",
+            "help_text": "How to get the (initial) Hessian.",
+        },
+        "hessian step": {
+            "default": "",
+            "kind": "string",
+            "default_units": "",
+            "enumeration": tuple(),
+            "format_string": "",
+            "description": "Step:",
+            "help_text": "Which step to get the Hessian from.",
+        },
         "recalc hessian": {
-            "default": "never",
+            "default": "at beginning",
             "kind": "integer",
             "default_units": "",
-            "enumeration": ("every step", "at beginning", "HF at begining", "never"),
+            "enumeration": (
+                "every step",
+                "at beginning",
+                "HF at beginning",
+                "5",
+                "10",
+            ),
             "format_string": "",
             "description": "Recalculate Hessian:",
             "help_text": (
@@ -82,6 +111,17 @@ class OptimizationParameters(gaussian_step.EnergyParameters):
             "description": "Type of coordinates:",
             "help_text": "The typ of coordinates to use in the minimization.",
         },
+        "ignore curvature error": {
+            "default": "no",
+            "kind": "boolean",
+            "default_units": "",
+            "enumeration": ("yes", "no"),
+            "format_string": "s",
+            "description": "Ignore incorrect curvature for TS:",
+            "help_text": (
+                "Whether to ignore incorrect curvvatures during TS optimizations"
+            ),
+        },
         "ignore unconverged optimization": {
             "default": "no",
             "kind": "boolean",
