@@ -4,7 +4,7 @@
 
 import logging
 import pprint
-import tkinter as tk
+import tkinter.messagebox as msg
 import tkinter.ttk as ttk
 
 import gaussian_step
@@ -95,36 +95,67 @@ class TkOptimization(gaussian_step.TkEnergy):
             self[key] = P[key].widget(opt_frame)
 
         # bindings...
-        for key in ("target",):
+        for key in ("target", "hessian"):
             self[key].bind("<<ComboboxSelected>>", self.reset_optimization)
             self[key].bind("<Return>", self.reset_optimization)
             self[key].bind("<FocusOut>", self.reset_optimization)
 
+        for key in ("geometry convergence",):
+            self[key].bind("<<ComboboxSelected>>", self.check_grid)
+            self[key].bind("<Return>", self.check_grid)
+            self[key].bind("<FocusOut>", self.check_grid)
+
         # Top level needs to call reset_dialog
         if self.node.calculation == "optimization":
             self.reset_dialog()
 
-    def reset_dialog(self, widget=None):
+    def check_grid(self, widget=None):
+        """Check the grid for the optimization parameters"""
+        convergence = self["geometry convergence"].get()
+        grid = self["integral grid"].get()
+
+        if "tight" in convergence.lower():
+            if grid != "SuperFine":
+                if msg.askyesno(
+                    "Tighten integral grid?",
+                    f"The integral grid is currently '{grid}'.\n"
+                    "Change to 'SuperFine'? (recommmended)",
+                    parent=self["frame"],
+                ):
+                    self["integral grid"].set("SuperFine")
+
+    def reset_dialog(self, widget=None, row=0):
         """Layout the widgets, letting our parents go first."""
         frame = self["frame"]
         for slave in frame.grid_slaves():
             slave.grid_forget()
 
-        row = 0
+        input_only = self["input only"].get().lower() == "yes"
+
         # Whether to just write input
-        self["input only"].grid(row=row, column=0, sticky=tk.W)
+        self["input only"].grid(row=row, column=0, sticky="w")
         row += 1
 
-        self["calculation"].grid(row=row, column=0)
+        # And how to handle files
+        if not input_only:
+            self["file handling"].grid(row=row, column=0, columnspan=2, sticky="w")
+            row += 1
+
+        self["calculation"].grid(row=row, column=0, columnspan=2)
         row += 1
         self.reset_calculation()
-        self["convergence frame"].grid(row=row, column=0)
+
+        self["convergence frame"].grid(row=row, column=0, columnspan=2)
         row += 1
         self.reset_convergence()
-        self["optimization"].grid(row=row, column=0)
-        row += 1
+
+        self["optimization"].grid(row=row, column=0, sticky="new")
         self.reset_optimization()
-        self["structure frame"].grid(row=row, column=0)
+        self["structure frame"].grid(row=row, column=1, sticky="new")
+        row += 1
+
+        frame.columnconfigure(0, weight=1)
+        frame.columnconfigure(1, weight=1)
 
         return row
 
@@ -134,30 +165,47 @@ class TkOptimization(gaussian_step.TkEnergy):
             slave.grid_forget()
 
         target = self["target"].get()
+        hessian = self["hessian"].get()
 
         widgets = []
         widgets2 = []
         row = 0
 
-        self["target"].grid(row=row, column=0, columnspan=2, sticky=tk.EW)
+        self["target"].grid(row=row, column=0, columnspan=2, sticky="ew")
         widgets.append(self["target"])
         row += 1
 
         if target not in ("minimum", "transition state"):
-            self["saddle order"].grid(row=row, column=1, sticky=tk.EW)
+            self["saddle order"].grid(row=row, column=1, sticky="ew")
             widgets2.append(self["saddle order"])
             row += 1
 
+        if target not in ("minimum"):
+            self["ignore curvature error"].grid(row=row, column=1, sticky="ew")
+            widgets2.append(self["ignore curvature error"])
+            row += 1
+
         for key in (
             "geometry convergence",
             "coordinates",
             "max geometry steps",
-            "recalc hessian",
-            "ignore unconverged optimization",
+            "hessian",
         ):
-            self[key].grid(row=row, column=0, columnspan=2, sticky=tk.EW)
+            self[key].grid(row=row, column=0, columnspan=2, sticky="ew")
             widgets.append(self[key])
             row += 1
 
-        sw.align_labels(widgets, sticky=tk.E)
-        sw.align_labels(widgets2, sticky=tk.E)
+        if hessian == "calculate":
+            for key in ("recalc hessian",):
+                self[key].grid(row=row, column=1, sticky="ew")
+                widgets2.append(self[key])
+                row += 1
+
+        for key in ("ignore unconverged optimization",):
+            self[key].grid(row=row, column=0, columnspan=2, sticky="ew")
+            widgets.append(self[key])
+            row += 1
+
+        w1 = sw.align_labels(widgets, sticky="e")
+        w2 = sw.align_labels(widgets2, sticky="e")
+        frame.columnconfigure(0, minsize=w1 - w2 + 30)
